multiformats.multihash.raw
==========================

.. automodule:: multiformats.multihash.raw

Hashfun
-------

.. autoclass:: multiformats.multihash.raw.Hashfun
    :members:

MultihashImpl
-------------

.. autodata:: multiformats.multihash.raw.MultihashImpl

exists
------

.. autofunction:: multiformats.multihash.raw.exists

get
---

.. autofunction:: multiformats.multihash.raw.get

register
--------

.. autofunction:: multiformats.multihash.raw.register

unregister
----------

.. autofunction:: multiformats.multihash.raw.unregister
